@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,32 +70,33 @@ public class FormContentWriterTest extends TestCase {
 
     private Map<String, Object> content = null;
     private DynamicFormDescription form = null;
-    
+
+    @Override
     public void setUp() throws Exception {
         content = new HashMap<String, Object>();
         form = new DynamicFormDescription();
-        
+
         form.add(FormElement.input("login", "Login Name")).add(FormElement.password("password", "Password")).add(FormElement.checkbox("checkbox", "Checkbox")).add(FormElement.link("url", "URL")).add(FormElement.link("absolute", "Absolute URL"));
-        
+
         content.put("login", "blupp");
         content.put("password", "geheim");
         content.put("checkbox", true);
         content.put("url", "/server/relative");
         content.put("absolute", "http://www.somewhere.invalid/absoluteURL");
-        
+
     }
-    
+
     public void testWrite() throws JSONException {
         JSONObject object = new FormContentWriter().write(form, content, "https://myserver.invalid");
         JSONAssertion assertion = new JSONAssertion().isObject()
             .hasKey("login").withValue("blupp")
-            .hasKey("password").withValue("xxxxxxxx")
             .hasKey("checkbox").withValue(true)
             .hasKey("url").withValue("https://myserver.invalid/server/relative")
             .hasKey("absolute").withValue("http://www.somewhere.invalid/absoluteURL")
+            .hasNoMoreKeys()
        .objectEnds();
-        
+
         assertValidates(assertion, object);
     }
-    
+
 }
